Struct rsync_list::Config [−][src]
#[non_exhaustive]pub struct Config<'a> { pub source: &'a OsStr, pub exclude: &'a [&'a OsStr], pub include: &'a [&'a OsStr], pub executable: &'a OsStr, pub links: bool, pub recursive: bool, }
Configuration for a list.
Many options refernce the rsync command line options and syntax. See https://download.samba.org/pub/rsync/rsync.html for the reference documentation on those options.
Fields (Non-exhaustive)
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: &'a OsStrThe source to list.
Example: rsync://example.com/path Example: me@example.com:/path
These are the same syntax as the rsync command line.
exclude: &'a [&'a OsStr]Patterns to exclude from the listing.
Example: www/*.gz
This corresponds to rsync’s –exclude flag.
include: &'a [&'a OsStr]Patterns not to exclude..
Example: www/*.tar.gz
This corresponds to rsync’s –include flag.
executable: &'a OsStrThe rsync executable to use.
This will be looked for in $PATH if it does not contain any directory
separators.
Default: rsync
links: boolIf links should be reported. If false links will be reported as the
file that they point to.
Note: The last modified time will always be that of the link, not that of the target.
Default: true
recursive: boolRecursively list the source.
Default: true
Implementations